Standard Library - SUP Language

# Standard Library

## Math

- `power of A and B`
- `min of A and B`, `max of A and B`
- `sqrt of X`, `floor of X`, `ceil of X`

## Strings

- `upper of S`, `lower of S`, `trim of S`, `concat of A and B`
- `join of SEP and LIST`

## Collections

- `make list of ...`, `push`, `pop`, `length of L`
- `make map`, `set "k" to v in map`, `get "k" from map`, `delete "k" from map`
- `get N from list`

## I/O and JSON

- `read file of PATH`, `write file of PATH and DATA`
- `json parse of STRING`, `json stringify of VALUE`
- `now` – current timestamp (ISO)

« Previous Next »